@@ -8,7 +8,9 @@ create table jaaql__user (
     deleted timestamptz,
     enc_totp_iv varchar(254),
     last_totp varchar(6),
-    alias varchar(32)
+    alias varchar(32),
+    sign_up_data text,
+    is_public boolean default false
 );
 CREATE UNIQUE INDEX jaaql__user_unq_email ON jaaql__user (email) WHERE (deleted is null);
 
@@ -48,7 +50,8 @@ create view jaaql__user_latest_password as (
         us.email,
         password_hash,
         us.enc_totp_iv,
-        us.last_totp
+        us.last_totp,
+        us.is_public
     FROM
         (SELECT
             the_user,
@@ -379,3 +382,24 @@ BEGIN
     UPDATE jaaql__node SET "name" = (left("name", 180) || '_deleted_') || current_timestamp::text, deleted = current_timestamp WHERE name = node_name;
 END
 $$ language plpgsql;
+
+create table jaaql__email_accounts (
+    account_name varchar(255) PRIMARY KEY not null,
+    send_name varchar(255) not null,
+    protocol varchar(4) not null,
+    check (protocol in ('smtp', 'imap')),
+    host varchar(255) not null,
+    port integer not null,
+    username varchar(255) not null,
+    deleted timestamptz default null
+);
+
+create table jaaql__email_history (
+    email_account varchar(255) not null,
+    FOREIGN KEY (email_account) references jaaql__email_accounts,
+    sent timestamptz not null default current_timestamp,
+    encrypted_subject text,
+    encrypted_recipients text,
+    encrypted_body text,
+    encrypted_attachments text
+);
\ No newline at end of file
